@@ -15,5 +15,5 @@ test_that("lift effect for titanic data set", {
   }else{
     load(file='lift_effect_test_v3.Rda')
   }
-  expect_equal(result, lift_effect_test)
+  expect_equivalent(result, lift_effect_test)
 })
